@@ -24,14 +24,12 @@ class NavigationBarNode ( template.Node ):
 	def render ( self, context ):
 		try :
 			bar = navigation_manager.get_bar( self.bar_name )
-
 			return render_to_string(template_path,{
 				"Bar"	: self.items,
 				"Name" : self.name
 			})
-
 		except :
-			return "-Bar %s Not Found-" % self.bar_name
+			return """<!--Bar "%s" Not Found-->""" % self.bar_name
 
 @register.tag
 def navigationbar_count ( parser, token = None):
@@ -44,3 +42,14 @@ class NavigationBarCountNode ( template.Node ):
 		except :
 			return ""
 
+@register.tag
+def navigationbar_items ( parser, token = None):
+	return NavigationBarItemsNode( )
+
+class NavigationBarItemsNode ( template.Node ):
+	def render ( self, context=None):
+		try :
+			return ".".join([ bar_name for bar_name, bar in navigation_manager.bars().items() ])
+		except :
+			return ""
+
